# remirepo/Fedora spec file for php-zendframework-zend-config
#
# Copyright (c) 2015-2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    2920e877a9f6dca9fa8f6bd3b1ffc2e19bb1e30d
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zendframework
%global gh_project   zend-config
%global php_home     %{_datadir}/php
%global library      Config
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.6.0
Release:        7%{?dist}
Summary:        Zend Framework %{library} component

License:        BSD
URL:            https://zendframework.github.io/%{gh_project}/
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

Patch0:         https://github.com/zendframework/zend-config/commit/27d5ba5c13cb4a576400f534057b69231190ac9d.patch

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 5.5
BuildRequires:  php-libxml
BuildRequires:  php-pcre
BuildRequires:  php-spl
BuildRequires:  php-xmlreader
BuildRequires:  php-xmlwriter
BuildRequires: (php-autoloader(%{gh_owner}/zend-stdlib)         >= 2.7   with php-autoloader(%{gh_owner}/zend-stdlib)      < 4)
# From composer, "require-dev": {
#        "zendframework/zend-filter": "^2.6",
#        "zendframework/zend-i18n": "^2.5",
#        "zendframework/zend-json": "^2.6.1",
#        "zendframework/zend-servicemanager": "^2.7.5 || ^3.0.3",
#        "fabpot/php-cs-fixer": "1.7.*",
#        "phpunit/PHPUnit": "~4.0"
BuildRequires: (php-autoloader(%{gh_owner}/zend-filter)         >= 2.6   with php-autoloader(%{gh_owner}/zend-filter)         < 3)
BuildRequires: (php-autoloader(%{gh_owner}/zend-i18n)           >= 2.5   with php-autoloader(%{gh_owner}/zend-i18n)           < 3)
# ignore max version, as test suite passes with v3
BuildRequires: (php-autoloader(%{gh_owner}/zend-json)           >= 2.6.1 with php-autoloader(%{gh_owner}/zend-json)           < 4)
BuildRequires: (php-autoloader(%{gh_owner}/zend-servicemanager) >= 2.7.5 with php-autoloader(%{gh_owner}/zend-servicemanager) < 4)
BuildRequires:  php-composer(phpunit/phpunit)                   >= 4.0
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^5.5 || ^7.0",
#        "zendframework/zend-stdlib": "^2.7 || ^3.0"
Requires:       php(language) >= 5.5
Requires:      (php-autoloader(%{gh_owner}/zend-stdlib)      >= 2.7      with php-autoloader(%{gh_owner}/zend-stdlib)      < 4)
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 2.5.2
Requires:       php-libxml
Requires:       php-pcre
Requires:       php-spl
Requires:       php-xmlreader
Requires:       php-xmlwriter
%if ! %{bootstrap}
# From composer, "suggest": {
#        "zendframework/zend-filter": "Zend\\Filter component",
#        "zendframework/zend-i18n": "Zend\\I18n component",
#        "zendframework/zend-json": "Zend\\Json to use the Json reader or writer classes",
#        "zendframework/zend-servicemanager": "Zend\\ServiceManager for use with the Config Factory to retrieve reader and writer instances"
%if 0%{?fedora} >= 21 || 0%{?rhel} >= 8
Suggests:       php-autoloader(%{gh_owner}/zend-filter)
Suggests:       php-autoloader(%{gh_owner}/zend-i18n)
Suggests:       php-autoloader(%{gh_owner}/zend-json)
Suggests:       php-autoloader(%{gh_owner}/zend-servicemanager)
%endif
%endif

Obsoletes:      php-ZendFramework2-%{library} < 2.5
Provides:       php-ZendFramework2-%{library} = %{version}
Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
Zend\Config is designed to simplify access to configuration data within
applications. It provides a nested object property-based user interface
for accessing this configuration data within application code. The
configuration data may come from a variety of media supporting hierarchical
data storage.

Documentation: https://zendframework.github.io/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}
%patch0 -p1

mv LICENSE.md LICENSE


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/Zend/Stdlib/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_home}/Zend/Filter/autoload.php',
    '%{php_home}/Zend/I18n/autoload.php',
    '%{php_home}/Zend/Json/autoload.php',
    '%{php_home}/Zend/ServiceManager/autoload.php',
]);
EOF


%install
mkdir -p   %{buildroot}%{php_home}/Zend/
cp -pr src %{buildroot}%{php_home}/Zend/%{library}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/Zend/%{library}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('ZendTest\\%{library}\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmd in php php56 php70 php71 php72 php73; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/Zend/%{library}


%changelog
* Tue Feb  5 2019 Remi Collet <remi@remirepo.net> - 2.6.0-7
- fix FTBFS with PHP 7.3, patch from
  https://github.com/zendframework/zend-config/pull/54
- use range dependencies

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Dec  7 2017 Remi Collet <remi@remirepo.net> - 2.6.0-4
- switch from zend-loader to fedora/autoloader

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb  5 2016 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- raise dependency on PHP >= 5.5
- raise dependency on zend-stdlib >= 2.7

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Oct  1 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-1
- normal build

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-0
- initial package, bootstrap build